Learn R Programming

xhaz (version 2.1.0)

BIC.bsplines: Bayesian Information Criterion for excess hazard model with baseline hazard following a B-splines functions

Description

Calculates the Bayesian Information Criterion' for fitted models from xhaz.

Usage

# S3 method for bsplines
BIC(object, ...)

Value

the value corresponds to the BIC calculated from the total log-likelihood of the fitted model if just one object is provided. If multiple objects are provided, a data.frame with columns corresponding to the objects and rows representing the number of parameters in the model (df) and the BIC.

Arguments

object

a fitted model object obtained from xhaz function

...

optionally more fitted model objects obtained from xhaz function

Examples

Run this code
# \donttest{
library("xhaz")

#Giorgi et al model: baseline excess hazard is a quadratic Bsplines
#                    function with two interior knots and allow here a
#                    linear and proportional effects for the covariates on
#                    baseline excess hazard.

fitphBS <- xhaz(formula = survival::Surv(time_year, status) ~ agec + race,
                data = simuData,
                ratetable = survival::survexp.us,
                interval = c(0, NA, NA, 6),
                rmap = list(age = 'age', sex = 'sex', year = 'date'),
                baseline = "bsplines", pophaz = "classic")

fitphBS
BIC(fitphBS)
# }

Run the code above in your browser using DataLab