Learn R Programming

xhaz (version 2.1.0)

as.predxhaz_list: Coerce a generic list of models (and subgroups) to a predxhaz_list

Description

Coerce a generic list of models (and subgroups) to a predxhaz_list

Usage

as.predxhaz_list(models, group_labels = NULL)

Value

An object of class predxhaz_list.

Arguments

models

Either: (A) a named list of objects coercible to predxhaz (one subgroup per model), or (B) a named list of models, where each model is a list of subgroups (e.g., list(grp0 = <pred>, grp1 = <pred>, ...)), each coercible to predxhaz.

group_labels

Optional named character vector mapping subgroup ids (names) to display labels. Missing names get their id as label.