Learn R Programming

xhaz (version 2.1.0)

breast: Simulated clinical trial data with non comparability bias in term of individuals expected hazard

Description

Simulated data

Usage

data(breast)

Arguments

Format

This dataset contains the following variables:

temps

Follow-up time (years)

statut

Vital status

age

Age at diagnosis

agecr

Centered and scaled age

date

date of diagnosis.

SEX

2 for female

armt

2 arms of treatment (0,1)

hosp

clinical centers

dept

department of residence

References

Goungounga, JA, Graff\'eo N, Charvat H, Giorgi R. “Correcting for heterogeneity and non-comparability bias in multicenter clinical trials with a rescaled random-effect excess hazard model.” Biometrical journal. Biometrische Zeitschrift vol. 65,4 (2023): e2100210. doi:10.1002/bimj.202100210.PMID: 36890623; (PubMed)

Examples

Run this code
data(breast)
summary(breast)

Run the code above in your browser using DataLab