Learn R Programming

xhaz (version 2.1.0)

exphaz: exphaz function

Description

Calculate the expected hazard and survival.

Usage

exphaz(
  formula = formula(data),
  data = sys.parent(),
  ratetable,
  rmap = list(age = NULL, sex = NULL, year = NULL),
  ratedata = sys.parent(),
  only_ehazard = TRUE,
  subset,
  na.action,
  scale = 365.2425
)

Value

An object of class list containing the following components:

ehazard

expected hazard calculated from the matching ratetable.

ehazardInt

cumulative expected hazard calculated from the matching ratetable. if only_ehazard=TRUE, this quantity is not provided.

dateDiag

date of diagnosis

Arguments

formula

a formula object of the Surv function with the response on the left of a ~ operator and the terms on the right. The response must be a survival object as returned by the Surv function (time in first and status in second).

data

a data frame in which to interpret the variables named in the formula

ratetable

a rate table stratified by age, sex, year (if missing, ratedata is used)

rmap

A named list mapping ratetable dimensions (e.g., age, sex, year, and any extras like dept, EDI) to column names in data.

ratedata

a data frame of the hazards mortality in general population.

only_ehazard

a boolean argument (by default, only_ehazard=TRUE). If TRUE, the cumulative population hazard is not provided.

subset

an expression indicating which subset of the rows in data should be used in the fit. All observations are included by default

na.action

a missing data filter function. The default is na.fail, which returns an error if any missing values are found. An alternative is na.exclude, which deletes observations that contain one or more missing values.

scale

a numeric argument specifying by default scale = 365.2425 (or using the value corresponding to attributes(ratetable)$cutpoints[[1]][2], often equal to 365.25) if the user wants to extract a yearly hazard rate, or scale = 1 if he wants to extract a daily hazard rate from a ratetable containing daily hazard rates for a matched subject from the population, defined as -log(1-q)/365.25 where q is the 1-year probability of death.

References

Goungounga JA, Touraine C, Graff\'eo N, Giorgi R; CENSUR working survival group. Correcting for misclassification and selection effects in estimating net survival in clinical trials. BMC Med Res Methodol. 2019 May 16;19(1):104. doi: 10.1186/s12874-019-0747-3. PMID: 31096911; PMCID: PMC6524224. (PubMed)

Therneau, T. M., Grambsch, P. M., Therneau, T. M., & Grambsch, P. M. (2000). Expected survival. Modeling survival data: extending the Cox model, 261-287.

Examples

Run this code
# \donttest{
library(survival)
library(survexp.fr)
library(xhaz)
fit.haz <- exphaz(
                formula = Surv(obs_time_year, event) ~ 1,
                data = dataCancer,
                ratetable = survexp.fr, only_ehazard = TRUE,
                rmap = list(age = 'age', sex = 'sexx', year = 'year_date')
)
# }

Run the code above in your browser using DataLab