- formula
a formula object of the function with the response on the left
of a ~ operator and the terms on the right. The response must be a
survival object as returned by the Surv function (time in first and status
in second).
- data
a data frame in which the variables named in the formula are to be interpreted.
- expected
name of the variable (must be given in quotes) representing
the population instantaneous hazard.
- expectedCum
name of the variable (must be given in quotes) representing
the population cumulative hazard.
- pophaz
specifies two possible arguments in character: classic and
rescaled. If pophaz = "classic" is chosen, it fits the models that do
not require the background mortality to be rescaled and assumes that the
comparability assumption holds; if pophaz = "rescaled" is chosen, it
fits the models that require that require the background mortality to be rescaled.
- base
functional form that should be used to model the baseline hazard.
Selection can be made between the following options: "weibull" for a Weibull
hazard, "exp.bs" for a hazard described by the exponential of a B-spline
(only B-splines of degree 1, 2 or 3 are accepted), "exp.ns" for a hazard
described by the exponential of a restricted cubic spline (also called 'natural spline'), "pw.cst" for a piecewise constant hazard. By default, base="weibull" as
in mexhaz R-package.
- degree
if base="exp.bs", degree represents the degree of the B-spline used.
Only integer values between 1 and 3 are accepted, and 3 is the default.
- knots
if base="exp.bs" or "exp.ns", knots is the vector
of interior knots of the spline. If base="pw.cst", knots is the vector
defining the endpoints of the time intervals on which the hazard is assumed
to be constant. By default, knots=NULL (that is, it produces a B-spline
with no interior knots if base="exp.bs", a linear B-spline with no interior
knots if base="exp.ns", or a constant hazard over the whole follow-up period
if base="pw.cst").
- bound
a vector of two numerical values corresponding to the boundary
knots of the spline functions. If base="exp.bs" or base="exp.ns",
computation of the B-spline basis requires that boundary knots be given.
The bound argument allows the user to specify these boundary knots.
If base="exp.bs", the interval defined by the boundary knots must at
least include the interval c(0,max(time)) (otherwise, there could be
problems with ill-conditioned bases). If base="exp.ns",
- n.gleg
corresponds to the number of quadrature nodes to be specified as in mexhaz.
- init
vector of initial values as in mexhaz.
- random
name of the variable to be entered as a random effect (must be
given between quotes), representing the cluster membership. As in mexhaz
random=NULL means that the function fits a fixed effects model.
- n.aghq
corresponds to the number of quadrature points to be specified
as in mexhaz for the estimation of the cluster-specific marginal
likelihoods by adaptative Gauss-Hermite quadrature.
- fnoptim
name of the R optimisation procedure used to maximise the
likelihood. Selection can be made between "nlm" (by default) and "optim".
Note: if exactGradHess=TRUE, this argument will be ignored
(fnoptim will be set automatically to "nlm").
- verbose
integer parameter representing the frequency at which the
current state of the optimisation process is displayed. If verbose=0 (default),
nothing is displayed.
- method
if fnoptim="optim", method represents the optimisation method to
be used by optim. By default, method="Nelder-Mead". This parameter is not
used if fnoptim="nlm".
- iterlim
if fnoptim="nlm", iterlim represents the maximum number of
iterations before the nlm optimisation procedure is terminated. By default,
iterlim is set to 10000. This parameter is not used if fnoptim="optim"
(in this case, the maximum number of iterations must be given as part of a
list of control parameters via the control argument: see the help page of optim
for further details).
- numHess
logical value allowing the user to choose between the Hessian
returned by the optimization algorithm (default) or the Hessian estimated by
the hessian function from the numDeriv package.
- print.level
his argument is only used if fnoptim="nlm". It determines
the level of printing during the optimisation process. The default value
(for the mexhaz function) is set to '1' which means that details on the
initial and final step of the optimisation procedure are printed (see the
help page of nlm for further details).
- exactGradHess
logical value allowing the user to decide whether
maximisation of the likelihood should be based on the analytic gradient and
Hessian computed internally (default, corresponding to exactGradHess=TRUE).
- gradtol
this argument is only used if fnoptim="nlm".
It corresponds to the tolerance at which the scaled gradient is considered
close enough to zero to terminate the algorithm. The default value depends on
the value of the argument exactGradHess.
- testInit
this argument is used only when exactGradHess=TRUE and
when the model is not an excess hazard random effect model. It instructs
the mexhaz function to try several vectors of initial values in case
optimization was not successful with the default (or user-defined) initial
values. Because optimization based on the analytical gradient and Hessian
is usually fast, this simple and empirical procedure proves useful to
increase the probability of convergence in cases when it is difficult
to specify appropriate initial values.
- keep.data
logical argument determining whether the dataset should be
kept in the object returned by the function: this can be useful in certain
contexts (e.g., to calculate cluster-specific posterior predictions from a
random intercept model) but might create unnecessarily voluminous objects.
The default value is set to FALSE.
- ...
other parameters used with the mexhazLT function