Learn R Programming

xhaz (version 2.1.0)

print.constant: A print.constant Function used to print a object of class constant

Description

This function present the estimated coefficients for the excess hazard baseline coefficient and for the covariate effects

Usage

# S3 method for constant
print(x, ci_type = "lognormal", digits = max(options()$digits - 4, 3), ...)

Value

Estimated parameters of the model in different scales for interpretation purposes.

Arguments

x

an object of class xhaz.constant

ci_type

method for confidence intervals calculation

digits

minimal number of significant digits.

...

additionnal parameters which can be used in the print function

See Also

xhaz, summary.constant, print.bsplines

Examples

Run this code

library("numDeriv")
library("survexp.fr")

data("simuData","rescaledData", "dataCancer")
# load the data sets 'simuData', 'rescaledData' and 'dataCancer'.

# Esteve et al. model: baseline excess hazard is a piecewise function
#                      linear and proportional effects for the covariates on
#                      baseline excess hazard.

set.seed(1980)
simuData2 <- simuData[sample(nrow(simuData), size = 500), ]

fit.estv2 <- xhaz(formula = Surv(time_year, status) ~ agec + race,
                  data = simuData2,
                  ratetable = survexp.us,
                  interval = c(0, NA, NA, NA, NA, NA, 6),
                  rmap = list(age = 'age', sex = 'sex', year = 'date'),
                  baseline = "constant", pophaz = "classic")


print(fit.estv2)


Run the code above in your browser using DataLab