Learn R Programming

xhaz (version 2.1.0)

print.predxhaz: A print.predxhaz Function used to print a object of class predxhaz

Description

This function present the print of the predict function

Usage

# S3 method for predxhaz
print(x, ...)

Value

an object of class data.frame containing the following components:

times.pts

The time at which the estimations of excess hazard and net survival are predicted

hazard

the predicted excess hazard at the fixed times

survival

the predicted net survival at the fixed times

Arguments

x

an object of class predxhaz

...

other parameters used for print function

Examples

Run this code

# \donttest{

library("xhaz")
library("survexp.fr")
library("splines")

data("dataCancer", package = "xhaz")   # load the data set in the package

fit.phBS <- xhaz(
        formula = Surv(obs_time_year, event) ~ ageCentre + immuno_trt,
        data = dataCancer, ratetable = survexp.fr,
        interval = c(0, NA, NA, max(dataCancer$obs_time_year)),
        rmap = list(age = 'age', sex = 'sexx', year = 'year_date'),
        baseline = "bsplines", pophaz = "classic")


fit.phBS


predicted <- predict(object = fit.phBS,
                     new.data = dataCancer[1:10,],
                     times.pts = c(seq(0,10,1)),
                     baseline = TRUE)



#a list of predicted hazard and survival at different time points
print(predicted)


#predicted hazard and survival at time points 10 years
do.call("cbind", predicted)[11,]
# }

Run the code above in your browser using DataLab