Coerce a generic list of models (and subgroups) to a predxhaz_list
as.predxhaz_list(models, group_labels = NULL)An object of class predxhaz_list.
Either:
(A) a named list of objects coercible to predxhaz (one subgroup per model), or
(B) a named list of models, where each model is a list of subgroups
(e.g., list(grp0 = <pred>, grp1 = <pred>, ...)), each coercible to predxhaz.
Optional named character vector mapping subgroup ids (names) to display labels. Missing names get their id as label.