- formula
a formula object of the Surv function with the
response on the left of a ~ operator and the terms on the right. The
response must be a survival object as returned by the Surv
function (time in first and status in second).
- data
a data frame in which to interpret the variables named in the
formula
- ratetable
a rate table stratified by age, sex,
year (if missing, ratedata is used)
- rmap
A named list mapping ratetable dimensions (e.g., age, sex, year, and any extras like dept, EDI) to column names in data.
- ratedata
a data frame of the hazards mortality in general population.
- only_ehazard
a boolean argument (by default, only_ehazard=TRUE).
If TRUE, the cumulative population hazard is not provided.
- subset
an expression indicating which subset of the rows in data
should be used in the fit. All observations are included by default
- na.action
a missing data filter function. The default is na.fail,
which returns an error if any missing values are found. An alternative is
na.exclude, which deletes observations that contain one or more missing
values.
- scale
a numeric argument specifying by default scale = 365.2425
(or using the value corresponding to attributes(ratetable)$cutpoints[[1]][2], often equal
to 365.25) if the user wants to extract a yearly hazard rate, or scale = 1 if he
wants to extract a daily hazard rate from a ratetable containing daily hazard rates for
a matched subject from the population, defined as -log(1-q)/365.25
where q is the 1-year probability of death.